<?php
if ( !defined('ABSPATH') ) {
	exit; // Exit if accessed directly
}
/**
 * Class to handle backend functionality
 */
if ( !class_exists('WWP_Wholesale_Pricing_Backend') ) {

	class WWP_Wholesale_Pricing_Backend {
		
		public function __construct() {
			add_action('admin_menu', array($this, 'wwp_register_custom_menu_page'));
			add_action('admin_init', array($this, 'wwp_request_options'));
			add_filter('woocommerce_product_data_tabs', array($this, 'wwp_add_wholesale_product_data_tab'), 99, 1);
			add_action('admin_enqueue_scripts', array($this, 'wwp_admin_script_style'));
			add_action('admin_head', array($this, 'wcpp_custom_style'));
			add_action('woocommerce_product_data_panels', array($this, 'wwp_add_wholesale_product_data_fields'));
			add_action('woocommerce_process_product_meta', array($this, 'wwp_woo_wholesale_fields_save'), 99);
			add_action('woocommerce_product_after_variable_attributes', array($this, 'wwp_variation_settings_fields'), 10, 3);
			add_action('woocommerce_save_product_variation', array($this, 'wwp_save_variation_settings_fields'), 10, 2);
			
		}
		public function wwp_request_options() {
			register_setting('wwp_wholesale_request_notifications', 'wwp_wholesale_user_registration_notification'); 
			register_setting('wwp_wholesale_request_notifications', 'wwp_wholesale_registration_notification_subject'); 
			register_setting('wwp_wholesale_request_notifications', 'wwp_wholesale_registration_notification_body');
		}
		
		public function wwp_admin_script_style() {
			wp_enqueue_style('wwp-style', WWP_PLUGIN_URL . 'assets/css/admin-style.css', array(), '1.0' );
		}
		public function wwp_register_custom_menu_page() {
		    global $submenu;
			add_menu_page(
				esc_html__('Wholesale Pricing', 'woocommerce-wholesale-pricing'),
				esc_html__('Wholesale', 'woocommerce-wholesale-pricing'),
				'manage_options',
				'wwp_wholesale',
				array($this, 'wwp_wholesale_page_callback'),
				'dashicons-store',
				58
			);
			add_submenu_page( 
				'wwp_wholesale', 
				esc_html__('Wholesale For WooCommerce', 'woocommerce-wholesale-pricing'), 
				esc_html__('Settings', 'woocommerce-wholesale-pricing'), 
				'manage_options', 
				'wwp_wholesale',
				array($this, 'wwp_wholesale_page_callback')
			);
			
			add_submenu_page( 
				'wwp_wholesale', 
				esc_html__('Notifications', 'woocommerce-wholesale-pricing'), 
				esc_html__('Notifications', 'woocommerce-wholesale-pricing'), 
				'manage_wholesale_notifications', 
				'wwp_wholesale_notifcations',
				array($this, 'wwp_wholesale_notifications_callback')
			);
		 
			add_submenu_page(
				'wwp_wholesale', 
				esc_html__('Registration Page', 'woocommerce-wholesale-pricing'), 
				esc_html__('Registration Setting', 'woocommerce-wholesale-pricing'),
				'manage_options',
				'wwp-registration-setting', 
				array($this,'wwp_wholesale_registration_page_callback')
			);
			 
			
			$submenu['wwp_wholesale'][] = array( '<b style="color:#fff">Get Pro Version</b>', 'manage_options' , 'https://woocommerce.com/products/wholesale-for-woocommerce/?aff=2878' );  
		}
		
				public function wwp_wholesale_notifications_callback() {
			?>
			<div class="wrap">
				<form method="post" action="options.php">
					<?php settings_errors(); ?>
					<?php settings_fields('wwp_wholesale_request_notifications'); ?>
					<?php do_settings_sections('wwp_wholesale_request_notifications'); ?>
					<table class="form-table wwp-main-settings">
						<tr>
							<td colspan="2"><h3><?php esc_html_e('New User Registration Notification', 'woocommerce-wholesale-pricing'); ?></h3><hr></td>	
						</tr>
						<tr>
							<th>
								<label for="wwp_wholesale_user_registration_notification"><?php esc_html_e('Registration Notification', 'woocommerce-wholesale-pricing'); ?></label>
							</th>
							<td>
								<?php $value=get_option('wwp_wholesale_user_registration_notification'); ?>
								<input type="checkbox" name="wwp_wholesale_user_registration_notification" value="yes" id="wwp_wholesale_user_registration_notification" <?php echo checked('yes', $value); ?>>
								<span><?php esc_html_e('When checked, an Email will be sent to user registration requested	.', 'woocommerce-wholesale-pricing'); ?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="wwp_wholesale_registration_notification_subject"><?php esc_html_e('Email Subject', 'woocommerce-wholesale-pricing'); ?></label>
							</th>
							<td>
								<?php $value=get_option('wwp_wholesale_registration_notification_subject'); ?>
								<input type="text" name="wwp_wholesale_registration_notification_subject" id="wwp_wholesale_registration_notification_subject" value="<?php echo esc_attr($value); ?>" class="regular-text"/>
							</td>
						</tr>
						<tr>
							<th>
								<label for="wwp_wholesale_registration_notification_body"><?php esc_html_e('Message', 'woocommerce-wholesale-pricing'); ?></label>
							</th>
							<td>
								<?php
									$content = html_entity_decode(get_option('wwp_wholesale_registration_notification_body'));
									echo wp_kses_post(wp_editor(
										$content,
										'wwp_wholesale_registration_notification_body',
										array('textarea_rows' => 3)
									)); 
								?>
								<p><?php esc_html_e('Email body for the new registration user role. Use {first_name}, {last_name}, {username}, {email}, {date}, {time} tag in body to get user email.', 'woocommerce-wholesale-pricing'); ?></p>
							</td>
						</tr>
						
					</table>
					<?php submit_button(); ?>
				</form>
			</div>
			<?php
		}
		
		public function wwp_wholesale_registration_page_callback() {
			$registrations = get_option('wwp_wholesale_registration_options');
			if ( isset($_POST['save_wwp_registration_setting']) ) {
				if ( isset($_POST['wwp_wholesale_settings_nonce']) || wp_verify_nonce( wc_clean($_POST['wwp_wholesale_settings_nonce']), 'wwp_wholesale_settings_nonce') ) {
					$registrations = isset($_POST['registrations']) ? wc_clean($_POST['registrations']) : '';
					update_option('wwp_wholesale_registration_options', $registrations);
				}
			} 
			?><div id="screen_fix"></div>
			<div id="registration_form_settings">
			
			<nav class="wholesale-tab-link nav-tab-wrapper wp-clearfix">
				<a href="<?php echo esc_html_e(wholesale_tab_link('')); ?>" class="nav-tab <?php echo esc_html_e(wholesale_tab_active('')); ?>" data-tab="wholesale-general-settings">
					<?php esc_html_e('General Settings', 'woocommerce-wholesale-pricing'); ?>
				</a>
				<a href="<?php echo esc_html_e(wholesale_tab_link('default-fields')); ?>" class="nav-tab <?php echo esc_html_e(wholesale_tab_active('default-fields')); ?>" data-tab="wholesale-default-settings">
					<?php esc_html_e('Default Fields', 'woocommerce-wholesale-pricing'); ?>
				</a>
				<a href="<?php echo esc_html_e(wholesale_tab_link('extra-fields')); ?>" class="nav-tab <?php echo esc_html_e(wholesale_tab_active('extra-fields')); ?>" data-tab="wholesale-extra-settings">
				 
					<?php  _e('Form Builder <span class="bagpro">Pro</span>' , 'woocommerce-wholesale-pricing'); ?>
				</a>
			</nav>
			
			<?php if (wholesale_load_form_builder()) { ?>
				<form action="" method="post">
					<?php wp_nonce_field('wwp_wholesale_settings_nonce', 'wwp_wholesale_settings_nonce'); ?>
					
					
					<table class="form-table" style="display: <?php echo esc_html_e(wholesale_content_tab_active('')); ?>">
						<tbody>
							<tr scope="row">
								<th><h4><label for=""><?php esc_html_e('Enable Billing Address form Default Fields', 'woocommerce-wholesale-pricing'); ?></label></h4></th>
								<td>
									<p>
										<label for="custommer_billing_address" class="switch">
										<?php
											$checked = '';
										if ( !isset($registrations) || empty($registrations) ) {
											$checked = 'checked';
										} else if ( isset( $registrations['custommer_billing_address'] ) && 'yes' == $registrations['custommer_billing_address'] ) {
											$checked = 'checked';
										} else {
											$checked = '';
										} 
										?>
											<input id="custommer_billing_address" type="checkbox"  value="yes" name="registrations[custommer_billing_address]" <?php echo esc_html($checked); ?> >
											<span class="slider round"></span>
										</label>
										<span data-tip="Enabling this option will allow default WooCommerce billing address field to appear on the front-end form." class="data-tip-top"><span class="woocommerce-help-tip"></span></span>
									</p>
								</td>
							</tr>
						</tbody>
					</table>
					<table class="form-table"  style="display: <?php echo esc_html_e(wholesale_content_tab_active('')); ?>">
						<tbody>
							<tr scope="row">
								<th><h4><label><?php esc_html_e('Enable Shipping Address form Default Fields', 'woocommerce-wholesale-pricing'); ?></label></h4></th>
								<td>
									<p>
										<?php
										$checked = '';
										if ( !isset($registrations) || empty($registrations) ) {
											$checked = 'checked';
										} elseif ( isset( $registrations['custommer_shipping_address'] ) && 'yes' == $registrations['custommer_shipping_address'] ) {
											$checked = 'checked';
										} else {
											$checked = '';
										} 
										?>
										<label for="custommer_shipping_address" class="switch">
											<input id="custommer_shipping_address" type="checkbox" value="yes" name="registrations[custommer_shipping_address]" <?php echo esc_html($checked); ?>>
											<span class="slider round"></span>
										</label>
										<span data-tip="Enabling this option will allow default WooCommerce shipping address field to appear on the front-end form." class="data-tip-top"><span class="woocommerce-help-tip"></span></span>
									</p>
								</td>
							</tr>
						</tbody>
					</table>
 
					 
					<div id="billing_address_fields" style="display:<?php echo esc_html_e(wholesale_content_tab_active('default-fields')); ?>">
					<h3><label for=""><?php esc_html_e('Billing Address form Fields', 'woocommerce-wholesale-pricing'); ?></label></h3>
						<table class="form-table">
							<tbody>
								<tr scope="row">
									<th><label for=""><?php esc_html_e('Billing First Name', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_first_name">
												<input type="checkbox" id="enable_billing_first_name" name="registrations[enable_billing_first_name]" value="yes" <?php echo ( isset($registrations['enable_billing_first_name']) && 'yes' == $registrations['enable_billing_first_name'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_first_name" placeholder="Custom label" name="registrations[billing_first_name]" value="<?php echo isset( $registrations['billing_first_name'] ) ? esc_attr($registrations['billing_first_name']) : ''; ?>" >
												<?php esc_html_e(' [ default label : "First Name" ]', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row">
									<th><label for=""><?php esc_html_e('Billing Last Name', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_last_name">
												<input type="checkbox" id="enable_billing_last_name" name="registrations[enable_billing_last_name]" value="yes" <?php echo ( isset($registrations['enable_billing_last_name']) && 'yes' == $registrations['enable_billing_last_name'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_last_name" placeholder="Custom label" name="registrations[billing_last_name]" value="<?php echo isset($registrations['billing_last_name']) ? esc_attr($registrations['billing_last_name']) : ''; ?>">
												<?php esc_html_e(' [ default label : "Last Name" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Company', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_company">
												<input type="checkbox" id="enable_billing_company" name="registrations[enable_billing_company]" value="yes" <?php echo ( isset($registrations['enable_billing_company']) && 'yes' == $registrations['enable_billing_company'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_company" placeholder="Custom label" name="registrations[billing_company]" value="<?php echo isset( $registrations['billing_company'] ) ? esc_attr($registrations['billing_company']) : ''; ?>" >
												<?php esc_html_e(' [ default label : "Company" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Address line 1 ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_address_1">
												<input type="checkbox" id="enable_billing_address_1" name="registrations[enable_billing_address_1]" value="yes"  <?php echo ( isset($registrations['enable_billing_address_1']) && 'yes' == $registrations['enable_billing_address_1'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_address_1" placeholder="Custom label" name="registrations[billing_address_1]" value="<?php echo isset($registrations['billing_address_1']) ? esc_attr($registrations['billing_address_1']) : ''; ?>">
												<?php esc_html_e(' [ default label : "Address line 1" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Address line 2 ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_address_2">
												<input type="checkbox" id="enable_billing_address_2" name="registrations[enable_billing_address_2]" value="yes" <?php echo ( isset($registrations['enable_billing_address_2']) && 'yes' == $registrations['enable_billing_address_2'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_address_2" placeholder="Custom label" name="registrations[billing_address_2]" value="<?php echo isset($registrations['billing_address_2']) ? esc_attr($registrations['billing_address_2']) : ''; ?>" >
												<?php esc_html_e('  [ default label : "Address line 2" ]', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('City ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_city">
												<input type="checkbox" id="enable_billing_city" name="registrations[enable_billing_city]" value="yes" <?php echo ( isset($registrations['enable_billing_city']) && 'yes' == $registrations['enable_billing_city'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_city" placeholder="Custom label" name="registrations[billing_city]" value="<?php echo isset($registrations['billing_city']) ? esc_attr($registrations['billing_city']) : ''; ?>"  >
												<?php esc_html_e(' [ default label : "City" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Postcode / ZIP ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_post_code">
												<input type="checkbox" id="enable_billing_post_code" name="registrations[enable_billing_post_code]" value="yes" <?php echo ( isset($registrations['enable_billing_post_code']) && 'yes' == $registrations['enable_billing_post_code'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_post_code"  placeholder="Custom label" name="registrations[billing_post_code]" value="<?php echo isset($registrations['billing_post_code']) ? esc_attr($registrations['billing_post_code']) : ''; ?>"  >
												<?php esc_html_e(' [ default label : "Postcode / ZIP" ]', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Countries ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_countries">
												<input type="checkbox" id="enable_billing_country" name="registrations[enable_billing_country]" value="yes" <?php echo ( isset($registrations['enable_billing_country']) && 'yes' == $registrations['enable_billing_country'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_countries" placeholder="Custom label" name="registrations[billing_countries]" value="<?php echo isset($registrations['billing_countries']) ? esc_attr($registrations['billing_countries']) : ''; ?>" >
												<?php esc_html_e(' [ default label : "Countries" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('States ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_countries">
												<input type="checkbox" id="enable_billing_state" name="registrations[enable_billing_state]" value="yes" <?php echo ( isset($registrations['enable_billing_state']) && 'yes' == $registrations['enable_billing_state'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_state"  placeholder="Custom label" name="registrations[billing_state]" value="<?php echo isset($registrations['billing_state']) ? esc_attr($registrations['billing_state']) : ''; ?>" >
												<?php esc_html_e(' [ default label : "States" ]', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label><?php esc_html_e('Phone ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_phone">
												<input type="checkbox" id="enable_billing_phone" name="registrations[enable_billing_phone]" value="yes" <?php echo ( isset($registrations['enable_billing_phone']) && 'yes' == $registrations['enable_billing_phone'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="billing_phone" placeholder="Custom label" name="registrations[billing_phone]" value="<?php echo isset($registrations['billing_phone']) ? esc_attr($registrations['billing_phone']) : ''; ?>">
												<?php esc_html_e(' [ default label : "Phone" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					
					<div id="shipping_address_fields" style="display:<?php echo esc_html_e(wholesale_content_tab_active('default-fields')); ?>;">
					<h3><label><?php esc_html_e('Shipping Address form Fields', 'woocommerce-wholesale-pricing'); ?></label></h3>
						<table class="form-table">
							<tbody>
								<tr scope="row">
									<th><label for=""><?php esc_html_e('Shipping First Name', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="shipping_first_name">
												<input type="checkbox" id="enable_shipping_first_name" name="registrations[enable_shipping_first_name]" value="yes" <?php echo ( isset($registrations['enable_shipping_first_name']) && 'yes' == $registrations['enable_shipping_first_name'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_first_name" placeholder="Custom label" name="registrations[shipping_first_name]" value="<?php echo isset($registrations['shipping_first_name']) ? esc_attr($registrations['shipping_first_name']) : ''; ?>">
												<?php esc_html_e('[ default label : "First Name" ]  ', 'woocommerce-wholesale-pricing'); ?>

											</label>
										</p>
									</td>
								</tr>
								<tr scope="row">
									<th><label for=""><?php esc_html_e('Shipping Last Name', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="shipping_last_name">
												<input type="checkbox" id="enable_shipping_last_name" name="registrations[enable_shipping_last_name]" value="yes" <?php echo ( isset($registrations['enable_shipping_last_name']) && 'yes' == $registrations['enable_shipping_last_name'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_last_name" placeholder="Custom label" name="registrations[shipping_last_name]" value="<?php echo isset($registrations['shipping_last_name']) ? esc_attr($registrations['shipping_last_name']) : ''; ?>">
												<?php esc_html_e(' [ default label : "Last Name" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Company', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_company">
												<input type="checkbox" id="enable_shipping_company" name="registrations[enable_shipping_company]" value="yes" <?php echo ( isset($registrations['enable_shipping_company']) && 'yes' == $registrations['enable_shipping_company'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_company" placeholder="Custom label" name="registrations[shipping_company]" value="<?php echo isset($registrations['shipping_company']) ? esc_attr($registrations['shipping_company']) : ''; ?>">
												<?php esc_html_e(' [ default label : "Company" ] ', 'woocommerce-wholesale-pricing'); ?>

											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Address line 1 ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="shipping_address_1">
												<input type="checkbox" id="enable_shipping_address_1" name="registrations[enable_shipping_address_1]" value="yes" value="yes" <?php echo ( isset($registrations['enable_shipping_address_1']) && 'yes' == $registrations['enable_shipping_address_1'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_address_1" placeholder="Custom label" name="registrations[shipping_address_1]" value="<?php echo isset($registrations['shipping_address_1']) ? esc_attr($registrations['shipping_address_1']) : ''; ?>">
												<?php esc_html_e('[ default label : "Address line 1" ]  ', 'woocommerce-wholesale-pricing'); ?>

											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Address line 2 ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="shipping_address_2">
												<input type="checkbox" id="enable_shipping_address_2" name="registrations[enable_shipping_address_2]" value="yes" <?php echo ( isset($registrations['enable_shipping_address_2']) && 'yes' == $registrations['enable_shipping_address_2'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_address_2" placeholder="Custom label" name="registrations[shipping_address_2]" value="<?php echo isset($registrations['shipping_address_2']) ? esc_attr($registrations['shipping_address_2']) : ''; ?>">
												<?php esc_html_e(' [ default label : "Address line 2" ]', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('City ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="shipping_city">
												<input type="checkbox" id="enable_shipping_city" name="registrations[enable_shipping_city]" value="yes" <?php echo ( isset($registrations['enable_shipping_city']) && 'yes' == $registrations['enable_shipping_city'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_city" placeholder="Custom label" name="registrations[shipping_city]" value="<?php echo isset($registrations['shipping_city']) ? esc_attr($registrations['shipping_city']) : ''; ?>">
												<?php esc_html_e(' [ default label : "City" ]', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Postcode / ZIP ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="shipping_post_code">
												<input type="checkbox" id="enable_shipping_post_code" name="registrations[enable_shipping_post_code]" value="yes" <?php echo ( isset($registrations['enable_shipping_post_code']) && 'yes' == $registrations['enable_shipping_post_code'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_post_code" placeholder="Custom label" name="registrations[shipping_post_code]" value="<?php echo isset($registrations['shipping_post_code']) ? esc_attr($registrations['shipping_post_code']) : ''; ?>">
												<?php esc_html_e(' [ default label : "Postcode / ZIP" ]', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row" >
									<th><label for=""><?php esc_html_e('Countries ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="shipping_countries">
												<input type="checkbox" id="enable_shipping_country" name="registrations[enable_shipping_country]" value="yes" <?php echo ( isset($registrations['enable_shipping_country']) && 'yes' == $registrations['enable_shipping_country'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_countries" placeholder="Custom label" name="registrations[shipping_countries]" value="<?php echo isset($registrations['shipping_countries']) ? esc_attr($registrations['shipping_countries']) : ''; ?>">
												<?php esc_html_e('[ default label : "Countries" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
								<tr scope="row">
									<th><label for=""><?php esc_html_e('States ', 'woocommerce-wholesale-pricing'); ?></label></th>
									<td>
										<p>
											<label for="billing_countries">
												<input type="checkbox" id="enable_shipping_state" name="registrations[enable_shipping_state]" value="yes" <?php echo ( isset($registrations['enable_shipping_state']) && 'yes' == $registrations['enable_shipping_state'] ) ? 'checked' : ''; ?>>
												<?php esc_html_e('Enable', 'woocommerce-wholesale-pricing'); ?>
												<input type="text" id="shipping_state" placeholder="Custom label" name="registrations[shipping_state]" value="<?php echo isset($registrations['shipping_state']) ? esc_attr($registrations['shipping_state']) : ''; ?>">
												<?php esc_html_e(' [ default label : "States" ] ', 'woocommerce-wholesale-pricing'); ?>
											</label>
										</p>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<p><button name="save_wwp_registration_setting" class="button-primary" type="submit" value="Save changes"><?php esc_html_e('Save changes', 'woocommerce-wholesale-pricing'); ?></button></p>
				</form>
				<?php 
			} else {
				?>
				<h1>GET IN PRO VERSION<h1> 
				<p class="propragraph">Upgrade to pro version of Wholesale for WooCommerce to access form builder In Pro Version you can add extra fields into your registration form which gives you more control over registration fields. Also, have the option to display Tax ID in billing address with Formbuilder and more features are available in <a target="_blank" href="https://woocommerce.com/products/wholesale-for-woocommerce/?aff=2878" class="btn " >Wholesale for WooCommerce Pro Version.</a></p>
				<a target="_blank" href="https://woocommerce.com/products/wholesale-for-woocommerce/?aff=2878">
				
				<img src="<?php echo WWP_PLUGIN_URL ?>assets/images/builder.png " style=" width: 100%;"></a> 
				
				<a target="_blank" href="https://woocommerce.com/products/wholesale-for-woocommerce/?aff=2878" class="btn wholesale_btn" >Get Wholesale Pro Version</a>
				<a target="_blank" href="https://docs.woocommerce.com/document/wholesale/wholesale-for-woocommerce/store-owners-guide-basic-concepts/#section-13" class="btn wholesale_btn" >FormBuilder Documentation</a>
				
				<?php 
			}
			?>
			</div>
			<div class="map_shortcode_callback">
				<p> <?php esc_html_e('Copy following shortcode, and paste in page where you would like to display wholesaler registration form.', 'woocommerce-wholesale-pricing'); ?></p>
				<div class="map_shortcode_copy"  onclick="copytoclipboard()"><span class="dashicons dashicons-admin-page"></span><label><?php esc_html_e('Copy', 'woocommerce-wholesale-pricing'); ?></label></div>
				<p> <input type="text" onfocus="this.select();" value="[wwp_registration_form]" readonly="readonly" name="shortcode" class="large-text code"> </p>
			</div>
			
			<?php
		}
		
		public function wwp_wholesale_page_callback() {
			$settings=get_option('wwp_wholesale_pricing_options', true);
			if ( isset($_POST['save-wwp_wholesale']) ) {
				if ( isset($_POST['wwp_wholesale_register_nonce']) || wp_verify_nonce( wc_clean($_POST['wwp_wholesale_register_nonce']), 'wwp_wholesale_register_nonce') ) {
					$settings = isset($_POST['options']) ? wc_clean($_POST['options']) : '';
					$settings['enable_registration_page'] = isset($settings['enable_registration_page']) ? 'yes' : 'no';
					$settings['wholesaler_prodcut_only'] = isset($settings['wholesaler_prodcut_only']) ? 'yes' : 'no';
					$settings['enable_upgrade'] = isset($settings['enable_upgrade']) ? 'yes' : 'no';
					$settings['disable_auto_role'] = isset($settings['disable_auto_role']) ? 'yes' : 'no';
					$settings['retailer_disabled'] = isset($settings['retailer_disabled']) ? 'yes' : 'no';
					$settings['save_price_disabled'] = isset($settings['save_price_disabled']) ? 'yes' : 'no';
					update_option('wwp_wholesale_pricing_options', $settings);
					
					if ( isset($_POST['_wwp_enable_wholesale_item']) ) {
						update_option('_wwp_enable_wholesale_item', 'yes');
					} else {
						update_option('_wwp_enable_wholesale_item', 'no');
					}
					if ( isset($_POST['wwp_wholesale_disable_coupons']) ) {
						update_option('wwp_wholesale_disable_coupons', 'yes');
					} else {
						update_option('wwp_wholesale_disable_coupons', 'no');
					}
					if ( isset($_POST['_wwp_wholesale_amount']) ) {
						update_option('_wwp_wholesale_amount', wc_clean($_POST['_wwp_wholesale_amount']) );
					} else {
						update_option('_wwp_wholesale_amount', '');
					}
					if ( isset($_POST['_wwp_wholesale_type']) ) {
						update_option('_wwp_wholesale_type', wc_clean($_POST['_wwp_wholesale_type']) );
					} else {
						update_option('_wwp_wholesale_type', '');
					}
					if ( isset($_POST['_wwp_wholesale_min_quantity']) ) {
						update_option('_wwp_wholesale_min_quantity', wc_clean($_POST['_wwp_wholesale_min_quantity']) );
					} else {
						update_option('_wwp_wholesale_min_quantity', '');
					}
					
				}
			} 
			 
			$disable_coupons = get_option('wwp_wholesale_disable_coupons');
			$enable 		 = get_option('_wwp_enable_wholesale_item');
			$amount			 = get_option('_wwp_wholesale_amount');
			$type 			 = get_option('_wwp_wholesale_type');
			$qty             = get_option('_wwp_wholesale_min_quantity');	 
			?>
			<form action="" method="post">
				<h2><?php esc_html_e('Wholesale For WooCommerce', 'woocommerce-wholesale-pricing'); ?></h2><hr>
				<?php wp_nonce_field('wwp_wholesale_register_nonce', 'wwp_wholesale_register_nonce'); ?>
				<table class="form-table">
					<tbody>
						<tr scope="row">
							<th colspan="2"><h2><?php esc_html_e('Price Labels', 'woocommerce-wholesale-pricing'); ?></h2></th>
						</tr>
						<tr scope="row">
							<th><label for="retailer_label"><?php esc_html_e('Retailer Price Label', 'woocommerce-wholesale-pricing'); ?></label></th>
							<td><input type="text" class="regular-text" name="options[retailer_label]" id="retailer_label" value="<?php echo isset($settings['retailer_label']) ? esc_html($settings['retailer_label']) : ''; ?>">
							<input id="retailer_disabled" type="checkbox" value="yes" name="options[retailer_disabled]" <?php echo ( isset($settings['retailer_disabled']) && 'yes' == $settings['retailer_disabled'] ) ? 'checked' : ''; ?>><label for="retailer_disabled"><?php esc_html_e('Label Hide', 'woocommerce-wholesale-pricing'); ?></label>
							</td>
						</tr>
						<tr scope="row">
							<th><label for="wholesaler_price_label"><?php esc_html_e('Wholesaler Price Label', 'woocommerce-wholesale-pricing'); ?></label></th>
							<td><input type="text" class="regular-text" name="options[wholesaler_label]" id="wholesaler_price_label" value="<?php echo isset($settings['wholesaler_label']) ? esc_html($settings['wholesaler_label']) : ''; ?>"></td>
						</tr>
						<tr scope="row">
							<th><label for="save_price_label"><?php esc_html_e('Save Price Label', 'woocommerce-wholesale-pricing'); ?></label></th>
							<td><input type="text" class="regular-text" name="options[save_label]" id="save_price_label" value="<?php echo isset($settings['save_label']) ? esc_html($settings['save_label']) : ''; ?>">
							<input id="save_price_disabled" type="checkbox" value="yes" name="options[save_price_disabled]" <?php echo ( isset($settings['save_price_disabled']) && 'yes' == $settings['save_price_disabled'] ) ? 'checked' : ''; ?>>
							<label for="save_price_disabled"><?php esc_html_e('Label Hide', 'woocommerce-wholesale-pricing'); ?></label>
							</td>
						</tr>
					</tbody>            
				</table>
				<h2><?php esc_html_e('Disable Coupons for wholesale user', 'woocommerce-wholesale-pricing'); ?></h2>		
				<table class="form-table">
					<tr>
						<th>
						<label for="wwp_wholesale_disable_coupons"><?php esc_html_e('Disable Coupons', 'woocommerce-wholesale-pricing'); ?></label>
						</th>
						<td scope="row">
						<input type="checkbox" name="wwp_wholesale_disable_coupons" id="wwp_wholesale_disable_coupons" value="yes" <?php echo ( 'yes' == $disable_coupons ) ? 'checked' : ''; ?>>
						<span><?php esc_html_e('Disable Coupons for wholesale user role.', 'woocommerce-wholesale-pricing'); ?></span>
						</td>
					</tr>
				</table>
				<h2><?php esc_html_e('Upgrade Customer', 'woocommerce-wholesale-pricing'); ?></h2>		
				<table class="form-table">
						<tr scope="row">
							<th><label for=""><?php esc_html_e('Enable Upgrade Tab', 'woocommerce-wholesale-pricing'); ?></label></th>
							<td>
								<label for="enable_upgrade">
									<input id="enable_upgrade" type="checkbox" value="yes" name="options[enable_upgrade]" <?php echo ( isset($settings['enable_upgrade']) && 'yes' == $settings['enable_upgrade'] ) ? 'checked' : ''; ?>>
									<?php esc_html_e(' Enable wholesale upgrade tab on my account page for non wholesale users', 'woocommerce-wholesale-pricing'); ?>
								</label>
							</td>
						</tr>
						<tr scope="row">
							<th><label for=""><?php esc_html_e('Upgrade Tab Text', 'woocommerce-wholesale-pricing'); ?></label></th>
							<td>
								<label for="upgrade_tab_text">
									<input type="text" class="regular-text" name="options[upgrade_tab_text]" id="upgrade_tab_text" value="<?php echo isset($settings['upgrade_tab_text']) ? esc_html($settings['upgrade_tab_text']) : ''; ?>" Placeholder="Label for Upgrade to Wholesaler tab">
								</label>
								<span data-tip='Display any text you want on the "Upgrade to Wholesaler" tab.' class="data-tip-top"><span class="woocommerce-help-tip"></span></span>
							</td>
						</tr>
				</table>
				<h2><?php esc_html_e('Wholesale Pricing Global Option', 'woocommerce-wholesale-pricing'); ?></h2>
					<table class="form-table">
						<tr>
							<th>
								<label for="_wwp_enable_wholesale_item">
									<?php esc_html_e('Enable Wholesale Prices', 'woocommerce-wholesale-pricing'); ?>
								</label>
							</th>
							<td scope="row">
								<input type="checkbox" name="_wwp_enable_wholesale_item" id="_wwp_enable_wholesale_item" value="yes" <?php checked('yes', $enable); ?>>
								<span><?php esc_html_e('Enable wholesale prices.', 'woocommerce-wholesale-pricing'); ?></span>
							</td>
						</tr>
						<tr>
							<th>
								<label for="_wwp_wholesale_type">
									<?php esc_html_e('Wholesale Discount Type', 'woocommerce-wholesale-pricing'); ?>
								</label>
							</th>
							<td scope="row">
								<select name="_wwp_wholesale_type" id="_wwp_wholesale_type" class="regular-text">
									<option value="fixed" <?php selected('fixed', $type); ?>><?php esc_html_e('Fixed Amount', 'woocommerce-wholesale-pricing'); ?></option>
									<option value="percent" <?php selected('percent', $type); ?>><?php esc_html_e('Percentage', 'woocommerce-wholesale-pricing'); ?></option>
								</select>
								<p><?php esc_html_e('Price type for wholesale products.', 'woocommerce-wholesale-pricing'); ?></p>
							</td>
						</tr>
						<tr>
							<th>
								<label for="_wwp_wholesale_amount">
									<?php esc_html_e('Enter Wholesale Amount', 'woocommerce-wholesale-pricing'); ?>
								</label>
							</th>
							<td scope="row">
								<input type="text" name="_wwp_wholesale_amount" id="_wwp_wholesale_amount" value="<?php esc_attr_e($amount); ?>" class="regular-text">
								<p><?php esc_html_e('Enter wholesale amount.', 'woocommerce-wholesale-pricing'); ?></p>
							</td>
						</tr>
						<tr>
							<th>
								<label for="_wwp_wholesale_min_quantity">
									<?php esc_html_e('Minimum Quantity', 'woocommerce-wholesale-pricing'); ?>
								</label>
							</th>
							<td scope="row">
								<input type="number" name="_wwp_wholesale_min_quantity" id="_wwp_wholesale_min_quantity" value="<?php esc_attr_e($qty); ?>" class="regular-text">
								<p><?php esc_html_e('Enter wholesale minimum quantity to apply discount.', 'woocommerce-wholesale-pricing'); ?></p>
							</td>
						</tr>
					</table>
				<p><button name="save-wwp_wholesale" class="button-primary" type="submit" value="Save changes"><?php esc_html_e('Save changes', 'woocommerce-wholesale-pricing'); ?></button></p>
			</form>
			<div id="wcwp" class="wrap" style="background: #FFF;">
				<div class="pro_container" style="background:url(<?php echo WWP_PLUGIN_URL.'assets/images/wholesale-banner.png'; ?>);">
				<h2>Pro Features</h2>
					<ol>		
						<li>User Roles</li>
						<li> Notifications </li>
						<li> Requests</li>
						<li> Registration Setting </li>
						<li> Bulk Pricing</li>
					</ol>
					
					<a href="https://woocommerce.com/products/wholesale-for-woocommerce/?aff=2878" class="get_pro_btn">Get Pro Now</a>
				</div>
			</div>
			<style>
			.pro_container{
				padding: 10px 20px 20px;
				background-position: right!important;
				background-size: 356px!important;
				background-repeat: no-repeat!important;
				}
			a.get_pro_btn {
				margin-top: 20px;
				display: block;
				background: #96588a;
				padding: 10px 20px;
				color: #FFF;
				text-decoration: none;
				border-radius: 30px;
				font-weight: bold;
				font-size: 16px;
				width: 105px;
				text-align: center;
			}
			a.get_pro_btn:hover{
				color:#FFF;
				background:#000;
			}

			</style>
			<?php
		}
		/**
		 * Initialize product wholesale data tab
		 * 
		 * @since   1.0
		 * @version 1.0
		 */
		public function wwp_add_wholesale_product_data_tab( $product_data_tabs ) {
			$product_data_tabs['wwp-wholesale-tab'] = array(
				'label' => esc_html__('Wholesale', 'woocommerce-wholesale-pricing'),
				'target' => 'wwp_wholesale_product_data',
			);
			return $product_data_tabs;
		}
		/**
		 * Initialize product wholesale data tab
		 * 
		 * @since   1.0
		 * @version 1.0
		 */
		public function wcpp_custom_style() {
			?>
			<style>
				.wwp-wholesale-tab_tab a:before {
					font-family: Dashicons;
					content: "\f240" !important;
				}
			</style>
			<?php
		}
		/**
		 * Product wholesale data tab single user 
		 * 
		 * @since   1.0
		 * @version 1.0
		 */
		public function wwp_add_wholesale_product_data_fields() {
			global $woocommerce, $post, $product; 
			?>
			<!-- id below must match target registered in above wwp_add_wholesale_product_data_tab function -->
			<div id="wwp_wholesale_product_data" class="panel woocommerce_options_panel">
				<?php
				wp_nonce_field('wwp_product_wholesale_nonce', 'wwp_product_wholesale_nonce');
				woocommerce_wp_checkbox(
					array(
						'id'            => '_wwp_enable_wholesale_item',
						'wrapper_class' => 'wwp_enable_wholesale_item',
						'label'         => esc_html__('Enable Wholesale Item', 'woocommerce-wholesale-pricing'),
						'description'   => esc_html__('Add this item for wholesale customers', 'woocommerce-wholesale-pricing')
					)
				);
				woocommerce_wp_select(
					array(
						'id'      => '_wwp_wholesale_type',
						'label'   => esc_html__('Wholesale Type', 'woocommerce-wholesale-pricing'),
						'options' => array(
							'fixed'   => esc_html__('Fixed Amount', 'woocommerce-wholesale-pricing'),
							'percent' => esc_html__('Percent', 'woocommerce-wholesale-pricing'),
						)
					)
				);
				echo '<div class="hide_if_variable">';
					woocommerce_wp_text_input(
						array(
							'id'          => '_wwp_wholesale_amount',
							'label'       => esc_html__('Enter Wholesale Amount', 'woocommerce-wholesale-pricing'),
							'placeholder' => get_woocommerce_currency_symbol() . '15',
							'desc_tip'    => 'true',
							'description' => esc_html__('Enter Wholesale Price (e.g 15)', 'woocommerce-wholesale-pricing')
						)
					);
					woocommerce_wp_text_input(
						array(
							'id'          => '_wwp_wholesale_min_quantity',
							'label'       => esc_html__('Minimum Quantiy', 'woocommerce-wholesale-pricing'),
							'placeholder' => '1',
							'desc_tip'    => 'true',
							'description' => esc_html__('Minimum quantity to apply wholesale price (default is 1)', 'woocommerce-wholesale-pricing'),
							'type'        => 'number',
							'custom_attributes' => array(
								'step'     => '1',
								'min'    => '1'
							)
						)
					);
				echo '</div>';
				echo '<div class="show_if_variable">';
				echo '<p>' . esc_html__('For Variable Product you can add wholesale price from variations tab', 'woocommerce-wholesale-pricing') . '</p>';
				echo '</div>';
				?>
			</div>
			<?php
		}
		/**
		 * Save product meta fields
		 * 
		 * @param   $post_id to save product meta
		 * @since   1.0
		 * @version 1.0
		 */
		public function wwp_woo_wholesale_fields_save( $post_id ) {
			if ( !isset($_POST['wwp_product_wholesale_nonce']) || !wp_verify_nonce( wc_clean($_POST['wwp_product_wholesale_nonce']), 'wwp_product_wholesale_nonce') ) {
				return;
			}
			// Wholesale Enable
			$woo_wholesale_enable = isset($_POST['_wwp_enable_wholesale_item']) ? wc_clean($_POST['_wwp_enable_wholesale_item']) : '';        
			update_post_meta($post_id, '_wwp_enable_wholesale_item', esc_attr($woo_wholesale_enable));
			// Wholesale Type
			$woo_wholesale_type = isset($_POST['_wwp_wholesale_type']) ? wc_clean($_POST['_wwp_wholesale_type']) : '';
			if ( !empty($woo_wholesale_type) ) {
				update_post_meta($post_id, '_wwp_wholesale_type', esc_attr($woo_wholesale_type));
			}
			// Wholesale Amount
			$woo_wholesale_amount = isset($_POST['_wwp_wholesale_amount']) ? wc_clean($_POST['_wwp_wholesale_amount']) : '';
			if ( !empty($woo_wholesale_amount) ) {
				update_post_meta($post_id, '_wwp_wholesale_amount', esc_attr($woo_wholesale_amount));
			}
			// Wholesale Minimum Quantity
			$wwp_wholesale_min_quantity = isset($_POST['_wwp_wholesale_min_quantity']) ? wc_clean($_POST['_wwp_wholesale_min_quantity']) : '';
			if ( !empty($wwp_wholesale_min_quantity) ) {
				update_post_meta($post_id, '_wwp_wholesale_min_quantity', esc_attr($wwp_wholesale_min_quantity));
			}
		}
		/**
		 * Product variations settings single user 
		 * 
		 * @since   1.0
		 * @version 1.0
		 */
		public function wwp_variation_settings_fields ( $loop, $variation_data, $variation ) {
			wp_nonce_field('wwp_variation_wholesale_nonce', 'wwp_variation_wholesale_nonce');
			woocommerce_wp_text_input(
				array(
					'id'          => '_wwp_wholesale_amount[' . esc_attr($variation->ID) . ']',
					'label'       => esc_html__('Enter Wholesale Price', 'woocommerce-wholesale-pricing'),
					'desc_tip'    => 'true',
					'description' => esc_html__('Enter Wholesale Price Here (e.g 15)', 'woocommerce-wholesale-pricing'),
					'value'       => get_post_meta($variation->ID, '_wwp_wholesale_amount', true),
					'custom_attributes' => array(
						'step'     => 'any',
						'min'    => '0'
					)
				)
			);
			woocommerce_wp_text_input(
				array(
					'id'          => '_wwp_wholesale_min_quantity[' . esc_attr($variation->ID) . ']',
					'label'       => esc_html__('Minimum Quantiy', 'woocommerce-wholesale-pricing'),
					'placeholder' => '1',
					'value'       =>  get_post_meta($variation->ID, '_wwp_wholesale_min_quantity', true),
					'desc_tip'    => 'true',
					'description' => esc_html__('Minimum quantity to apply wholesale price (default is 1)', 'woocommerce-wholesale-pricing'),
					'type'              => 'number',
					'custom_attributes' => array(
						'step'     => '1',
						'min'    => '1'
					)
				)
			);
		}
		/**
		 * Save product variations settings single user 
		 * 
		 * @since   1.0
		 * @version 1.0
		 */
		public function wwp_save_variation_settings_fields ( $post_id ) {
			if ( !isset($_POST['wwp_variation_wholesale_nonce']) || !wp_verify_nonce( wc_clean($_POST['wwp_variation_wholesale_nonce']), 'wwp_variation_wholesale_nonce') ) {
				return;
			}
			$variable_wholesale = isset( $_POST['_wwp_wholesale_amount'][ $post_id ] ) ? wc_clean($_POST['_wwp_wholesale_amount'][ $post_id ]) : '';
			if ( !empty($variable_wholesale) ) {
				update_post_meta($post_id, '_wwp_wholesale_amount', esc_attr($variable_wholesale));
			}
			$wholesale_min_quantity = isset($_POST['_wwp_wholesale_min_quantity'][ $post_id ]) ? wc_clean($_POST['_wwp_wholesale_min_quantity'][ $post_id ]) : '';
			if ( !empty($wholesale_min_quantity) ) {
				update_post_meta($post_id, '_wwp_wholesale_min_quantity', esc_attr($wholesale_min_quantity));
			}
		}
	}
	new WWP_Wholesale_Pricing_Backend();
}